@@ -1,4 +1,5 @@
 import sys
+from typing import Optional
 
 from .site_randomizers import site_randomizers
 
@@ -13,7 +14,7 @@ def get_rando_permissions_tuples() -> list:
         app_label, model = randomizer_cls.model_cls()._meta.label_lower.split(".")
         verbose_name = randomizer_cls.model_cls()._meta.verbose_name
         rando_tuples.append((f"{app_label}.view_{model}", f"Can view {verbose_name}"))
-        if not randomizer_cls.is_blinded_trial:
+        if not randomizer_cls.trial_is_blinded:
             rando_tuples.append(
                 (
                     f"{app_label}.display_{model}",
@@ -35,7 +36,7 @@ export_rando = [
 
 
 # post_update_func
-def update_rando_group_permissions(auth_updater):
+def update_rando_group_permissions(auth_updater, app_label: Optional[str]):
     """Update group permissions for each registered randomizer class."""
     for randomizer_cls in site_randomizers._registry.values():
         if auth_updater.verbose:
@@ -55,7 +56,7 @@ def update_rando_group_permissions(auth_updater):
         )
 
 
-def make_randomizationlist_view_only(auth_updater):
+def make_randomizationlist_view_only(auth_updater, app_label: Optional[str]):
     for randomizer_cls in site_randomizers._registry.values():
         randomizer_cls.apps = auth_updater.apps
         app_label, model = randomizer_cls.model_cls()._meta.label_lower.split(".")
